# coding: utf-8

"""
    FINBOURNE Workflow API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic.v1 import StrictStr, Field, BaseModel, Field, conlist, constr 
from lusid_workflow.models.calendar_reference import CalendarReference

class ScheduleMatchingPatternContext(BaseModel):
    """
    Context for a Schedule Matching Pattern  # noqa: E501
    """
    time_zone:  StrictStr = Field(...,alias="timeZone", description="The time zone to use") 
    holiday_calendars: Optional[conlist(CalendarReference)] = Field(None, alias="holidayCalendars", description="References to any Holiday Calendars to use")
    __properties = ["timeZone", "holidayCalendars"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def __str__(self):
        """For `print` and `pprint`"""
        return pprint.pformat(self.dict(by_alias=False))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ScheduleMatchingPatternContext:
        """Create an instance of ScheduleMatchingPatternContext from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in holiday_calendars (list)
        _items = []
        if self.holiday_calendars:
            for _item in self.holiday_calendars:
                if _item:
                    _items.append(_item.to_dict())
            _dict['holidayCalendars'] = _items
        # set to None if holiday_calendars (nullable) is None
        # and __fields_set__ contains the field
        if self.holiday_calendars is None and "holiday_calendars" in self.__fields_set__:
            _dict['holidayCalendars'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ScheduleMatchingPatternContext:
        """Create an instance of ScheduleMatchingPatternContext from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ScheduleMatchingPatternContext.parse_obj(obj)

        _obj = ScheduleMatchingPatternContext.parse_obj({
            "time_zone": obj.get("timeZone"),
            "holiday_calendars": [CalendarReference.from_dict(_item) for _item in obj.get("holidayCalendars")] if obj.get("holidayCalendars") is not None else None
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Workflow API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic.v1 import StrictStr, Field, BaseModel, Field, StrictStr, conlist 

class ErrorDetail(BaseModel):
    """
    Defines a Failure Response as a DTO  # noqa: E501
    """
    id:  Optional[StrictStr] = Field(None,alias="id", description="The id of the failed item that this error relates to.") 
    type:  Optional[StrictStr] = Field(None,alias="type", description="The type of failure that occurred.") 
    detail:  Optional[StrictStr] = Field(None,alias="detail", description="Description of the failure that occurred.") 
    error_details: Optional[conlist(Dict[str, StrictStr])] = Field(None, alias="errorDetails", description="Information about the particular instance of the failure (supplied information depends on the type of failure).")
    __properties = ["id", "type", "detail", "errorDetails"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def __str__(self):
        """For `print` and `pprint`"""
        return pprint.pformat(self.dict(by_alias=False))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ErrorDetail:
        """Create an instance of ErrorDetail from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if id (nullable) is None
        # and __fields_set__ contains the field
        if self.id is None and "id" in self.__fields_set__:
            _dict['id'] = None

        # set to None if type (nullable) is None
        # and __fields_set__ contains the field
        if self.type is None and "type" in self.__fields_set__:
            _dict['type'] = None

        # set to None if detail (nullable) is None
        # and __fields_set__ contains the field
        if self.detail is None and "detail" in self.__fields_set__:
            _dict['detail'] = None

        # set to None if error_details (nullable) is None
        # and __fields_set__ contains the field
        if self.error_details is None and "error_details" in self.__fields_set__:
            _dict['errorDetails'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ErrorDetail:
        """Create an instance of ErrorDetail from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ErrorDetail.parse_obj(obj)

        _obj = ErrorDetail.parse_obj({
            "id": obj.get("id"),
            "type": obj.get("type"),
            "detail": obj.get("detail"),
            "error_details": obj.get("errorDetails")
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Workflow API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic.v1 import StrictStr, Field, BaseModel, Field, StrictBool, StrictStr, constr, validator 
from lusid_workflow.models.read_only_states import ReadOnlyStates
from lusid_workflow.models.value_constraints import ValueConstraints

class TaskFieldDefinition(BaseModel):
    """
    Defines a Task Definition Field  # noqa: E501
    """
    name:  StrictStr = Field(...,alias="name", description="The name of this Field") 
    type:  StrictStr = Field(...,alias="type", description="The value type for the field. Available values are: \"String\", \"Decimal\", \"DateTime\", \"Boolean\")") 
    read_only_states: Optional[ReadOnlyStates] = Field(None, alias="readOnlyStates")
    value_constraints: Optional[ValueConstraints] = Field(None, alias="valueConstraints")
    display_name:  Optional[StrictStr] = Field(None,alias="displayName", description="Display name for field definition") 
    description:  Optional[StrictStr] = Field(None,alias="description", description="Description for field definition") 
    category:  Optional[StrictStr] = Field(None,alias="category", description="Category for field definition") 
    contains_url: Optional[StrictBool] = Field(None, alias="containsUrl", description="Field contains url")
    __properties = ["name", "type", "readOnlyStates", "valueConstraints", "displayName", "description", "category", "containsUrl"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def __str__(self):
        """For `print` and `pprint`"""
        return pprint.pformat(self.dict(by_alias=False))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TaskFieldDefinition:
        """Create an instance of TaskFieldDefinition from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of read_only_states
        if self.read_only_states:
            _dict['readOnlyStates'] = self.read_only_states.to_dict()
        # override the default output from pydantic by calling `to_dict()` of value_constraints
        if self.value_constraints:
            _dict['valueConstraints'] = self.value_constraints.to_dict()
        # set to None if display_name (nullable) is None
        # and __fields_set__ contains the field
        if self.display_name is None and "display_name" in self.__fields_set__:
            _dict['displayName'] = None

        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict['description'] = None

        # set to None if category (nullable) is None
        # and __fields_set__ contains the field
        if self.category is None and "category" in self.__fields_set__:
            _dict['category'] = None

        # set to None if contains_url (nullable) is None
        # and __fields_set__ contains the field
        if self.contains_url is None and "contains_url" in self.__fields_set__:
            _dict['containsUrl'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TaskFieldDefinition:
        """Create an instance of TaskFieldDefinition from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TaskFieldDefinition.parse_obj(obj)

        _obj = TaskFieldDefinition.parse_obj({
            "name": obj.get("name"),
            "type": obj.get("type"),
            "read_only_states": ReadOnlyStates.from_dict(obj.get("readOnlyStates")) if obj.get("readOnlyStates") is not None else None,
            "value_constraints": ValueConstraints.from_dict(obj.get("valueConstraints")) if obj.get("valueConstraints") is not None else None,
            "display_name": obj.get("displayName"),
            "description": obj.get("description"),
            "category": obj.get("category"),
            "contains_url": obj.get("containsUrl")
        })
        return _obj
